.. _help:

Get Help
========

Welcome to the Falcon community! We are a pragmatic group of HTTP enthusiasts
working on the next generation of web apps and cloud services. We would love
to have you join us and share your ideas.

Please help us spread the word and grow the community!

FAQ
---
First, :ref:`take a quick look at our FAQ <faq>` to see if your question has
already been addressed. If not, or if the answer is unclear, please don't
hesitate to reach out via one of the channels below.

Chat
----
The Falconry community on Gitter is a great place to ask questions and
share your ideas. You can find us in `falconry/user
<https://gitter.im/falconry/user>`_. We also have a
`falconry/dev <https://gitter.im/falconry/dev>`_ room for discussing
the design and development of the framework itself.

Per our
`Code of Conduct <https://github.com/falconry/falcon/blob/master/CODEOFCONDUCT.md>`_,
we expect everyone who participates in community discussions to act
professionally, and lead by example in encouraging constructive
discussions. Each individual in the community is responsible for
creating a positive, constructive, and productive culture.

Submit Issues
-------------
If you have an idea for a feature, run into something that is harder to
use than it should be, or find a bug, please let the crew know
in `falconry/dev <https://gitter.im/falconry/dev>`_ or by
`submitting an issue <https://github.com/racker/falcon/issues>`_. We
need your help to make Falcon awesome!

Pay it Forward
--------------
We'd like to invite you to help other community members with their
questions in `falconry/user
<https://gitter.im/falconry/user>`_, and to help peer-review
`pull requests <https://github.com/racker/falcon/pulls>`_. If you use the
Chrome browser, we recommend installing the
`NotHub extension <http://nothub.org/>`_ to stay up to date with PRs.

If you would like to contribute a new feature or fix a bug in the
framework, please check out our
`Contributor's Guide <https://github.com/falconry/falcon/blob/master/CONTRIBUTING.md>`_
for more information.

We'd love to have your help!

Code of Conduct
---------------
All contributors and maintainers of this project are subject to our `Code
of Conduct <https://github.com/falconry/falcon/blob/master/CODEOFCONDUCT.md>`_.

